from setuptools import setup

setup(name='dsnd_by_cs',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dsnd_by_cs'],
      author = 'Camila Santos',
      zip_safe=False)
